@@ -593,6 +593,9 @@ RESOURCENOTFOUND_FILENOTEXIST = 'ResourceNotFound.FileNotExist'
 # 资源不存在：人物。
 RESOURCENOTFOUND_PERSON = 'ResourceNotFound.Person'
 
+# 没有开通服务。
+RESOURCENOTFOUND_SERVICENOTEXIST = 'ResourceNotFound.ServiceNotExist'
+
 # 资源不存在：模板不存在。
 RESOURCENOTFOUND_TEMPLATENOTEXIST = 'ResourceNotFound.TemplateNotExist'
 
